@@ -32,7 +32,7 @@ class WorkforceAddressSummary(models.Model):
 class ConstanceSetting(models.Model):
     slug = models.CharField(max_length=100)
     setting_name = models.TextField()
-    setting_value = models.TextField()
+    setting_value = models.TextField(null=True)
     last_reported = models.DateTimeField()
 
     class Meta:
@@ -78,9 +78,9 @@ class TemplateChangeRequestSummary(models.Model):
     currency = models.CharField(max_length=3, null=True, blank=True)
     requested_changes = ArrayField(models.CharField(max_length=100), default=list, blank=True, verbose_name="Requested modifications")
     status = models.CharField(max_length=20, db_index=True)
-    status_changed_requested = models.DateTimeField()
-    status_changed_approved = models.DateTimeField()
-    status_changed_completed = models.DateTimeField()
+    status_changed_requested = models.DateTimeField(null=True)
+    status_changed_approved = models.DateTimeField(null=True)
+    status_changed_completed = models.DateTimeField(null=True)
     template_key = models.CharField(max_length=200)
     template_name = models.CharField(max_length=200)
     template_content_type_model = models.CharField(max_length=200)
